from django import forms
from django.forms import widgets
from django.conf import settings


class UniversalUploaderWidget(widgets.ClearableFileInput):
    template_name = 'admin/widgets/universal_uploader_widget.html'

    def __init__(self, attrs=None):
        super(UniversalUploaderWidget, self).__init__(attrs=attrs)

    @property
    def media(self):
        extra = '' if settings.DEBUG else '.min'
        return forms.Media(
            js=(
                'admin/js/universal-uploader-widget%s.js' % extra,
            ),
            css={
                'screen': (
                    'admin/css/universal-uploader-widget%s.css' % extra,
                ),
            },
        )


class ImageUploaderWidget(UniversalUploaderWidget):
    def get_context(self, name, value, attrs):
        context = super(ImageUploaderWidget, self).get_context(
            name, value, attrs)
        context['widget'].update({
            'file_type': 'image',
            'input_accept': '.jpg,.jpeg,.png,.gif,.webp'
        })
        return context


class AudioUploaderWidget(UniversalUploaderWidget):
    def get_context(self, name, value, attrs):
        context = super(AudioUploaderWidget, self).get_context(
            name, value, attrs)
        context['widget'].update({
            'file_type': 'audio',
            'input_accept': '.mp3'
        })
        return context


class VideoUploaderWidget(UniversalUploaderWidget):
    def get_context(self, name, value, attrs):
        context = super(VideoUploaderWidget, self).get_context(
            name, value, attrs)
        context['widget'].update({
            'file_type': 'video',
            'input_accept': '.mp4'
        })
        return context


class PdfUploaderWidget(UniversalUploaderWidget):
    def get_context(self, name, value, attrs):
        context = super(PdfUploaderWidget, self).get_context(
            name, value, attrs)
        context['widget'].update({
            'file_type': 'pdf',
            'input_accept': '.pdf'
        })
        return context

    @property
    def media(self):
        extra = '' if settings.DEBUG else '.min'
        return forms.Media(
            js=('admin/vendor/pdf.worker.min.js',
                'admin/js/universal-uploader-widget%s.js' % extra,
                ),
            css={
                'screen': (
                    'admin/css/universal-uploader-widget%s.css' % extra,
                ),
            },
        )



#!/usr/bin/env python
import os
from setuptools import setup, find_packages

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

setup(
    name='django-universal-uploader-widget',
    version='0.2.1',
    description='Simple Universal Uploader Widget for Django-Admin',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Sandro Salles',
    author_email='sandro@snippet.com.br',
    url='https://github.com/sandro-salles/django-universal-uploader-widget',
    license='MIT',
    packages=find_packages(
        exclude=("universal_uploader_widget_demo.*",
                 "universal_uploader_widget_demo", )
    ),
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='django,admin,widget,universal,uploader',
)



from django import forms
from django.contrib import admin
from django.conf import settings

class UniversalUploaderInline(admin.StackedInline):
    template = 'admin/edit_inline/universal_uploader.html'
    extra = 0

    @property
    def media(self):
        extra = '' if settings.DEBUG else '.min'
        return forms.Media(
            js = [
                'admin/js/universal-uploader-inline%s.js' % extra
            ],
            css = {
                'screen': [
                    'admin/css/universal-uploader-inline%s.css' % extra,
                ]
            }
        )

